@@ -111,7 +111,11 @@ QStringList AppStreamUtils::appstreamIds(const QUrl &appstreamUrl)
     ret += appstreamUrl.host().isEmpty() ? appstreamUrl.path() : appstreamUrl.host();
     if (appstreamUrl.hasQuery()) {
         QUrlQuery query(appstreamUrl);
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
         ret << query.queryItemValue(QStringLiteral("alt")).split(QLatin1Char(','), QString::SkipEmptyParts);
+#else
+        ret << query.queryItemValue(QStringLiteral("alt")).split(QLatin1Char(','), Qt::SkipEmptyParts);
+#endif
     }
     return ret;
 }
